@@ -22,7 +22,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-__version__ = "0.4.13"
+__version__ = "0.5.1"
 
 import sys
 
@@ -62,6 +62,7 @@ from qff.price.query import (
     get_price,
     history,
     attribute_history,
+    get_bars,
     get_stock_name,
     get_stock_list,
     get_st_stock,
@@ -75,7 +76,7 @@ from qff.price.query import (
     get_security_info
 )
 
-from qff.price.report import (
+from qff.price.finance import (
     get_financial_data,
     get_valuation,
     query_valuation,
@@ -93,23 +94,23 @@ from qff.price.fetch import (
     fetch_ticks,
 )
 from qff.frame.context import (
-    strategy,
     context,
     g,
     Context,
-    Portfolio,
-    Position,
-    RUNTYPE,
-    RUNSTATUS,
-    Strategy
 )
+from qff.frame.portfolio import Portfolio
+from qff.frame.position import Position
+from qff.frame.const import RUN_TYPE, RUN_STATUS, ORDER_TYPE, ORDER_STATUS
 
 from qff.frame.order import (
-    order_amount,
+    Order,
+    order,
     order_value,
     order_target,
     order_target_value,
-    order_cancel
+    order_cancel,
+    get_orders,
+    get_open_orders
 )
 
 from qff.frame.api import (
@@ -119,7 +120,6 @@ from qff.frame.api import (
     run_daily,
     run_file,
     set_universe,
-    del_universe,
     pass_today
 )
 
@@ -160,7 +160,5 @@ from qff.helper.formula import (
 
 from qff.helper.indicator import ind_ma, ind_macd, ind_atr, ind_kdj, ind_rsi, ind_boll
 from qff.helper.common import filter_st_stock, filter_paused_stock, filter_20pct_stock, select_zt_stock
-from qff.price.cache import get_current_data, CacheData
-from qff.frame.risk import Risk
-from qff.frame.perf import Perf
+from qff.price.cache import get_current_data, UnitData
 from qff.frame.evaluation import strategy_eval
